@@ -2,6 +2,10 @@
 ## spatio-temporal kriging ##
 #############################
 
+debug_time_unit = function(tUnit) {
+    # message("Using the following time unit: ", tUnit)
+}
+
 STsolve = function(A, b, X) {
   # V = A$T %x% A$S -- a separable covariance; solve A x = b for x
   # kronecker: T %x% S vec(L) = vec(c0) <-->  S L T = c0
@@ -51,13 +55,13 @@ krigeST <- function(formula, data, newdata, modelList, beta, y, ...,
                     bufferNmax=2, progress=TRUE) {
   stopifnot(inherits(modelList, "StVariogramModel") || is.function(modelList))
   return_stars = if (inherits(data, "stars")) {
-	if (!requireNamespace("sf", quietly = TRUE))
-		stop("sf required: install that first") # nocov
-	if (!requireNamespace("stars", quietly = TRUE))
-		stop("stars required: install that first") # nocov
-  	data = as(data, "STFDF")
-	newdata = as(newdata, "STFDF")
-	TRUE
+    if (!requireNamespace("sf", quietly = TRUE))
+      stop("sf required: install that first") # nocov
+    if (!requireNamespace("stars", quietly = TRUE))
+      stop("stars required: install that first") # nocov
+    data = as(data, "STFDF")
+    newdata = as(newdata, "STFDF")
+    TRUE
   } else
     FALSE
   stopifnot(inherits(data, c("STF", "STS", "STI")) & inherits(newdata, c("STF", "STS", "STI"))) 
@@ -75,19 +79,20 @@ krigeST <- function(formula, data, newdata, modelList, beta, y, ...,
     attr(modelList, "temporal unit") <- tUnit
   } else {
     tUnit <- tUnitModel
-    message("Using the following time unit: ", tUnit)
+    debug_time_unit(tUnit)
   }
   
   if(nmax < Inf) { # local neighbourhood ST kriging:
-    ret = krigeST.local(formula = formula, data = data, 
+    ret = krigeST.local( formula = formula, data = data, 
                          newdata = newdata, modelList = modelList, beta=beta, # y=y, # for later use
                          nmax = nmax, stAni = stAni, 
                          computeVar = computeVar, fullCovariance = fullCovariance, 
                          bufferNmax = bufferNmax, progress = progress)
-    if (return_stars) # xxx
-		return(stars::st_as_stars(as(ret, "STFDF")))
-	else
-		return(ret)
+
+    if (return_stars)
+      return(stars::st_as_stars(as(ret, "STFDF")))
+    else
+      return(ret)
   }
   
   df <- krigeST.df(formula = formula, data = data, newdata = newdata, 
@@ -99,11 +104,11 @@ krigeST <- function(formula, data, newdata, modelList, beta, y, ...,
   
   # wrapping the predictions in ST*DF again
   if (!fullCovariance) {
-	ret = addAttrToGeom(geometry(newdata), df)
+    ret = addAttrToGeom(geometry(newdata), df)
     if (return_stars)
-	  stars::st_as_stars(as(ret, "STFDF"))
-	else
-	  ret
+      stars::st_as_stars(as(ret, "STFDF"))
+    else
+      ret
   } else
     df
 }
